==> pulumi-3.113.0.tar.gz: pulumi-3.113.0/sdk/python/lib/test/langhost/versions/test_versions.py <==
# Copyright 2016-2021, Pulumi Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from os import path
from ..util import LanghostTest


class TestVersions(LanghostTest):
    def test_versions(self):
        self.run_test(
            program=path.join(self.base_path(), "versions"),
            expected_resource_count=3)

    def register_resource(self, _ctx, _dry_run, ty, name, _resource, _dependencies, _parent, _custom, protect,
                          _provider, _property_deps, _delete_before_replace, _ignore_changes, _version, _import,
                          _replace_on_changes, _providers, source_position):
        if name == "testres":
            self.assertEqual(_version, "0.19.1")
        elif name == "testres2":
            self.assertEqual(_version, "0.19.2")
        elif name == "testres3":
            self.assertEqual(_version, "")
        else:
            self.fail(f"unknown resource: {name}")
        return {
            "urn": self.make_urn(ty, name),
            "id": name,
            "object": {}
        }

    def invoke(self, _ctx, token, args, _provider, version):
        if token == "test:index:doit":
            self.assertEqual("0.19.1", version)
        elif token == "test:index:doit_v2":
            self.assertEqual("0.19.2", version)
        elif token == "test:index:doit_no_version":
            self.assertEqual("", version)
        return [], args

==> pulumi-3.165.0.tar.gz: pulumi-3.165.0/sdk/python/lib/test/langhost/versions/test_versions.py <==
# Copyright 2016-2021, Pulumi Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from os import path
from ..util import LanghostTest


class TestVersions(LanghostTest):
    def test_versions(self):
        self.run_test(
            program=path.join(self.base_path(), "versions"), expected_resource_count=3
        )

    def register_resource(
        self,
        _ctx,
        _dry_run,
        ty,
        name,
        _resource,
        _dependencies,
        _parent,
        _custom,
        protect,
        _provider,
        _property_deps,
        _delete_before_replace,
        _ignore_changes,
        _version,
        _import,
        _replace_on_changes,
        _providers,
        source_position,
    ):
        if name == "testres":
            self.assertEqual(_version, "0.19.1")
        elif name == "testres2":
            self.assertEqual(_version, "0.19.2")
        elif name == "testres3":
            self.assertEqual(_version, "")
        else:
            self.fail(f"unknown resource: {name}")
        return {"urn": self.make_urn(ty, name), "id": name, "object": {}}

    def invoke(self, _ctx, token, args, _provider, version):
        if token == "test:index:doit":
            self.assertEqual("0.19.1", version)
        elif token == "test:index:doit_v2":
            self.assertEqual("0.19.2", version)
        elif token == "test:index:doit_no_version":
            self.assertEqual("", version)
        return [], args
